@@ -4,4 +4,4 @@ utils::globalVariables(
     "cycle", "fixture", "line", "force", "youden_plot_data_2", "gage_1", "gage_2", "grouping_var_distinct", "ref_values_tbl",
     "ref_values_tbl_joined", "ref_value", "avg", "lcl", "ucl", "moving_range", "timeseries_scatterplot_data", "n", "index",
     "paneled_theme_element", "variable", "overall_mean", "wb", "polar_small_multiples_data", "low_high", "Pair", "Variable",
-    "Value", "color_label", "black", "red", "unit", "filepath_complete"))
+    "Value", "color_label", "black", "red", "unit", "filepath_complete", "value"))
